@@ -1,8 +1,9 @@
 from .consts import *
 
-from reportlab.platypus import Image, Paragraph
+from reportlab.platypus import Image, Paragraph, Table
 from reportlab.lib.utils import ImageReader
 from reportlab.lib.units import mm, cm
+from reportlab.lib import colors
 
 from abc import abstractclassmethod
 from typing import Union
@@ -17,6 +18,7 @@ class FrigelReportCreator():
     def __init__(self):
         self.logo = DEFAULT_LOGO_PATH
         self.machine = DEFAULT_MACHINE_PATH
+        self.syncro_logo = DEFAULT_SYNCRO_LOGO_PATH
 
 
     @abstractclassmethod
@@ -87,8 +89,28 @@ class FrigelReportCreator():
             spacing (float)
         '''
         self.lastPositionY += spacing
-        
-        
+
+    def heading(self) -> None:
+        '''
+        add heading for page
+        '''
+        self.drawLogo()
+        self.drawSyncro()
+    
+    def footer(self) -> None:
+        '''
+        add footer for page
+        '''
+        table_footer = Table(data=[['Performance Report', 'www.frigel.com', 'Pag. {}'.format(self.canvas.getPageNumber())]], colWidths=[210, 210])
+        table_footer.setStyle([ ("FONTSIZE", (0,0), (-1,-1), 12),
+                                ("FONTNAME", (0,0), (-1,-1), DEFAULT_FONT),
+                                ("VALIGN", (0,0), (-1,-1), 'BOTTOM'),
+                                ('LINEAFTER',(0,0),(1,0), .5, DEFAULT_FOOTER_COLOR),
+                                ("ALIGN", (0,0), (2,0), "CENTER"),
+                                ("TEXTCOLOR", (0,1), (0,-1), DEFAULT_FOOTER_COLOR),])
+        table_footer.wrapOn(self.canvas, self.width, self.height)
+        table_footer.drawOn(self.canvas,  *self.coord(0, 290, mm))
+    
     def newPage(self) -> None:
         '''
         creates a new pdf page
@@ -96,7 +118,8 @@ class FrigelReportCreator():
         self.canvas.showPage()
         self.lastPositionX = 0
         self.lastPositionY = DEFAULT_STARTING_POSITION
-        self.drawLogo()
+        self.heading()
+        self.footer()
         
     
     def drawOnCanvas(self, object: any, x: float, y: float) -> None:
@@ -120,15 +143,23 @@ class FrigelReportCreator():
         '''
         logo_object = self.get_image(self.logo, 5*cm)
         logo_object.wrapOn(self.canvas, self.width, self.height)
-        logo_object.drawOn(self.canvas, *self.coord(self.logoPositionX, self.logoPositionY + logo_object.drawHeight/2, mm))
+        logo_object.drawOn(self.canvas, *self.coord(self.logoPositionX + 15, self.logoPositionY + logo_object.drawHeight/2, mm))
+    
+    def drawSyncro(self) -> None:
+        '''
+        draws the Syncro logo on the page
+        '''
+        syncro_logo_object = self.get_image(self.syncro_logo, 3*cm)
+        syncro_logo_object.wrapOn(self.canvas, self.width, self.height)
+        syncro_logo_object.drawOn(self.canvas, *self.coord(160, self.logoPositionY +  syncro_logo_object.drawHeight/1.5, mm))
     
     def drawMachine(self) -> None:
         '''
         draws Machine on the page
         '''
-        logo_object = self.get_image(self.machine, 8*cm)
+        logo_object = self.get_image(self.machine, 7*cm)
         logo_object.wrapOn(self.canvas, self.width, self.height)
-        logo_object.drawOn(self.canvas, *self.coord(15, 0 + logo_object.drawHeight/2, mm))
+        logo_object.drawOn(self.canvas, *self.coord(self.logoPositionX + 10, 0 + logo_object.drawHeight-140, mm))
         
         
     def coord(self, x, y, unit=1) -> None:
@@ -142,7 +173,7 @@ class FrigelReportCreator():
         output:
             x, y (float, float)
         '''
-        x, y = x * unit, self.height -  y * unit
+        x, y = x * unit, self.height - y * unit
         return x, y    
     
     
